@@ -2,25 +2,16 @@
 The formatting module provides classes for formatting simulation/analysis
 records in different ways: summary, list or table; and in different mark-up
 formats: currently text or HTML.
-
-Classes
--------
-
-TextFormatter - formats records as text
-HTMLFormatter - formats records as HTML
-
-Function
---------
-
-get_formatter() - return an approriate Formatter object for a given requested
-                  format.
 """
 
 import textwrap
+import cgi
 
 fields = ['label', 'timestamp', 'reason', 'outcome', 'duration', 'repository',
           'main_file', 'version', 'script_arguments', 'executable',
-          'parameters', 'input_data', 'launch_mode', 'output_data', 'tags']
+          'parameters', 'input_data', 'launch_mode', 'output_data',
+          'user', 'tags']
+
 
 class Formatter(object):
     
@@ -28,15 +19,27 @@ class Formatter(object):
         self.records = records
         
     def format(self, mode='short'):
+        """
+        Format a record according to the given mode. ``mode`` may be 'short',
+        'long' or 'table'.
+        """
         return getattr(self, mode)()
 
 
 class TextFormatter(Formatter):
+    """
+    Format the information from a list of Sumatra records as text.
+    """
     
     def short(self):
+        """Return a list of record labels, one per line."""
         return "\n".join(record.label for record in self.records)
             
     def long(self, text_width=80, left_column_width=17):
+        """
+        Return detailed information about a list of records, as text with a
+        limited column width. Lines that are too long will be wrapped round.
+        """
         output = ""
         for record in self.records:
             output += "-" * text_width + "\n"
@@ -72,6 +75,10 @@ class TextFormatter(Formatter):
         return output
     
     def table(self):
+        """
+        Return information about a list of records as text, in a simple
+        tabular format.
+        """
         tt = TextTable(fields, self.records)
         return str(tt)
     
@@ -103,25 +110,66 @@ class TextTable(object):
         for row in self.rows:
             output += format % tuple(str(getattr(row, header))[:self.max_column_width] for header in self.headers)
         return output
-        
 
-class HTMLFormatter(Formatter):
+
+class ShellFormatter(Formatter):
+    """
+    Create a shell script that can be used to repeat a series of computations.
+    """
     
     def short(self):
+        output = "#!/bin/sh\n"
+        for record in self.records:
+            output += "\n# %s\n" % record.label
+            output += "# Originally run at %s by %s" % (record.timestamp, record.user)
+            # add info about original environment
+            # add info about dependencies and versions
+            output += "cd %s\n" % record.launch_mode.working_directory
+            output += "%s -r %s\n" % (record.repository.use_version_cmd, record.version)
+            # if record.diff:
+            #     todo - need to apply diff
+            # may need to write suitable parameter file - just write it or add a cat command to the bash script?
+            # todo - need to handle pre_run
+            # can we add assertions about the SHA1 hash of any input files?
+            output += record.launch_mode.generate_command() + "\n"
+        return output
+    
+    def long(self):
+        # perhaps have all the comments in the long version but not the short one
+        return self.short()
+
+
+class HTMLFormatter(Formatter):
+    """
+    Format information about a group of Sumatra records as HTML fragments, to
+    be included in a larger document.
+    """
+    
+    def short(self):
+        """
+        Return a list of record labels as an HTML unordered list.
+        """
         return "<ul>\n<li>" + "</li>\n<li>".join(record.label for record in self.records) + "</li>\n</ul>"
     
     def long(self):
+        """
+        Return detailed information about a list of records as an HTML
+        description list.
+        """
         def format_record(record):
             output = "  <dt>%s</dt>\n  <dd>\n    <dl>\n" % record.label
             for field in fields:
-                output += "      <dt>%s</dt><dd>%s</dd>\n" % (field, getattr(record, field))
+                output += "      <dt>%s</dt><dd>%s</dd>\n" % (field, cgi.escape(str(getattr(record, field))))
             output += "    </dl>\n  </dd>"
             return output
         return "<dl>\n" + "\n".join(format_record(record) for record in self.records) + "\n</dl>"
 
     def table(self):
+        """
+        Return detailed information about a list of records as an HTML table.
+        """
         def format_record(record):
-            return "  <tr>\n    <td>" + "</td>\n    <td>".join(str(getattr(record, field)) for field in fields) + "    </td>\n  </tr>"
+            return "  <tr>\n    <td>" + "</td>\n    <td>".join(cgi.escape(str(getattr(record, field))) for field in fields) + "    </td>\n  </tr>"
         return "<table>\n" + \
                "  <tr>\n    <th>" + "</th>\n    <th>".join(field.title() for field in fields) + "    </th>\n  </tr>\n" + \
                "\n".join(format_record(record) for record in self.records) + \
@@ -129,11 +177,16 @@ class HTMLFormatter(Formatter):
 
 
 class TextDiffFormatter(Formatter):
+    """
+    Format information about the differences between two Sumatra records in
+    text format.
+    """
     
     def __init__(self, diff):
         self.diff = diff
         
     def short(self):
+        """Return a summary of the differences between two records."""
         def yn(x):
             return x and "yes" or "no"
         D = self.diff
@@ -163,11 +216,14 @@ class TextDiffFormatter(Formatter):
                 yn(D.input_data_differ),
                 yn(D.script_arguments_differ),
                 yn(D.parameters_differ),
-                yn(D.data_differs))
+                yn(D.output_data_differ))
             )
         return output
     
     def long(self):
+        """
+        Return a detailed description of the differences between two records.
+        """
         output = ''
         if self.diff.executable_differs:
             output += "Executable differences:\n"
@@ -213,28 +269,36 @@ class TextDiffFormatter(Formatter):
             output += "Script argument differences:\n"
             for record in (self.diff.recordA, self.diff.recordB):
                 output += "  %s: %s\n" % (record.label, record.script_arguments)
-        diffs = self.diff.data_differences
-        if diffs:
+        AnotB, BnotA = self.diff.output_data_differences
+        if AnotB or BnotA:
             output += "Output data differences:\n"
-            for name, (depA, depB) in diffs.items():
-                if depA and depB:
-                    output += "  %s\n" % name
-                    output += "    A: size=%s\n" % depA.metadata['size']
-                    output += "    B: size=%s\n" % depB.metadata['size']
-                elif depB is None:
-                    output += "  %s is generated by %s but not by %s" % (name, self.diff.recordA.label, self.diff.recordB.label)
-                elif depA is None:
-                    output += "  %s is generated by %s but not by %s" % (name, self.diff.recordB.label, self.diff.recordA.label)
+            if AnotB:
+                output += "  Generated by %s:\n" % self.diff.recordA.label
+                for key in AnotB:
+                    output += "    %s\n" % key 
+            if BnotA:
+                output += "  Generated by %s:\n" % self.diff.recordB.label
+                for key in BnotA:
+                    output += "    %s\n" % key 
         return output
-    
+
+
 formatters = {
     'text': TextFormatter,
     'html': HTMLFormatter,
     'textdiff': TextDiffFormatter,
 }
-        
+
 def get_formatter(format):
+    """
+    Return a :class:`Formatter` object of the appropriate type. ``format``
+    may be 'text, 'html' or 'textdiff'
+    """
     return formatters[format]
 
 def get_diff_formatter():
-    return TextDiffFormatter
\ No newline at end of file
+    """
+    Return a :class:`DiffFormatter` object of the appropriate type. Only
+    text format is currently available.
+    """
+    return TextDiffFormatter
