@@ -34,9 +34,9 @@ class TestPythonModuleFunctions(unittest.TestCase):
     
     def test__find_versions_by_attribute(self):
         import main
-        self.assertEqual(df.python.find_version_by_attribute(main), "1.2.3b")
-        del main.get_version
         self.assertEqual(df.python.find_version_by_attribute(main), "1.2.3a")
+        del main.__version__
+        self.assertEqual(df.python.find_version_by_attribute(main), "1.2.3b")
         
     def test__find_versions_from_egg(self):
         dep = df.python.Dependency("main", os.path.join(self.example_project, "main.py"))
@@ -60,13 +60,33 @@ class TestCoreModuleFunctions(unittest.TestCase):
     def setUp(self):
         self.example_project = os.path.join(tmpdir, "python")
         assert os.path.exists(self.example_project)
+        self.somemodule_path = os.path.abspath(os.path.join(self.example_project, "subpackage", "somemodule.py"))
 
     def test__find_versions(self):
         #better to test this using mocks
         dep = df.python.Dependency("main", os.path.join(self.example_project, "main.py"))
         df.core.find_versions([dep], [df.python.find_versions_from_egg])
         self.assertEqual(dep.version, "1.2.3egg")
-        
+
+    def test__find_file_full_path(self):
+        self.assertEqual(df.core.find_file(os.path.join(self.example_project, "subpackage", "somemodule.py"),
+                                           None,
+                                           None),
+                         self.somemodule_path)
+    
+    def test__find_file_current_directory(self):
+        self.assertEqual(df.core.find_file("somemodule.py",
+                                           os.path.join(self.example_project, "subpackage"),
+                                           []),
+                         self.somemodule_path)
+    
+    def test__find_file_nonexistentfile(self):
+        self.assertRaises(IOError,
+                          df.core.find_file,
+                          "adifferentmodule.py",
+                          os.path.join(self.example_project, "subpackage"),
+                          [])
+    
         
 class TestMainModuleFunctions(unittest.TestCase):
     
@@ -111,6 +131,10 @@ class TestPythonDependency(unittest.TestCase):
         dep = df.python.Dependency("main", os.path.join(self.example_project, "main.py"), version="1.2.3b")
         self.assertEqual(dep.version, "1.2.3b")
 
+    def test__from_module(self):
+        dep = df.python.Dependency.from_module(sys.modules['numpy'], None)
+        self.assertEqual(dep.name, "numpy")
+
     def test__str(self):
         dep = df.python.Dependency("main", "/some/path")
         str(dep)
@@ -156,9 +180,7 @@ class TestNEURONDependency(unittest.TestCase):
         dep1 = df.neuron.Dependency(os.path.join(self.example_project, "main.hoc"))
         dep2 = df.neuron.Dependency(os.path.join(self.example_project, "dependency.hoc"))
         self.assertNotEqual(dep1, dep2)
-        
-    def test__init__with_nonexistent_path(self):
-        self.assertRaises(IOError, df.neuron.Dependency, "foo.hoc")
+
 
 def setup():
     global tmpdir
